package de.hdm_stuttgart.mi.sd1.aufgabe1;

/**
 * Hilfsmethoden.
 *
 */
public class Helper {

   /**
    * Spezialwert: Es gibt keinen Index mit den geforderten Eigenschaften. Dies ist konsistent, da ein
    * »echter« Arrayindex mindestens den Wert 0 haben muss.
    */
   static public final int INDEX_NOEXIST = -1; 


   /**
    * Erzeuge in Abhängigkeit vom übergebenen Wert eine Zeichenkette.
    * 
    * @param n Der bestimmende Eingangswert.
    * 
    * @return In Abhängigkeit vom Eingangswert:
    * 
    *    <ul>
    *      <li>"Toll", falls der Eingangswert durch 3 aber nicht durch 5 teilbar ist.</li>
    *      <li>"Super", falls der Eingangswert durch 5, aber nicht durch 3 teilbar ist.</li>
    *      <li>Der Zahlenwert als String (z.B. "7"), falls der Wert weder durch 3 noch durch 5 teilbar ist.</li>
    *      <li>"Supertoll", falls der Eingangswert sowohl durch 3 als auch durch 5 teilbar ist.</li>
    *    </ul>
    */
   static public String getSuperToll(int n) {
      if (0 == n % 5 && 0 == n % 3) {
         return "Supertoll";
      } else if (n % 5 == 0) {
         return "Super";
      } else if (n % 3 == 0) {
         return "Toll";
      } else {
         return Integer.toString(n);
      }
   }

   /**
    * <p>Der Index des ersten Arrayelements, welches echt größer ist als
    * die Summe aller Vorgänger.</p>
    * 
    * <p>Beispiel: Im Array {2, -1, 1, 5, -3, 22} ist der Index »3« zum Wert 5 gesucht,
    *   da der zugehörige Arraywert »5« noch vor der »22« größer wird, als die Summe
    *   2 - 1 + 1 == 2 aller Vorgänger.</p>
    * 
    * @param werte null oder ein beliebiges Array aus Ganzzahlen.
    * 
    * @return Falls das Array null ist, weniger als zwei Elemente enthält oder kein Wert größer als die
    *   Summe aller Vorgänger ist, so wird der Spezialwert {@link #INDEX_NOEXIST} zurückgegeben. 
    *   Ansonsten der Index des ersten gefundenen Werts gemäß obiger Beschreibung.
    *   
    */
   static public int maxVorgaenger(final int[] werte) {
      if (null != werte && 2 <= werte.length) {
         int summe = werte[0];
         for (int i = 1; i < werte.length; i++) {
            if (summe < werte[i]) {
               return i;
            } else {
               summe += werte[i];
            }
         }
      }
      return INDEX_NOEXIST;// Nix gefunden oder null oder weniger als 2 Werte
   }

   /**
    * Finde das n-te ungerade Element einer Wertefolge.
    * 
    * <p>Beispiel: Im Array {3, 2, 0, 1, 4} ist der Wert »1« an der Indexposition »3« das zweite
    *  ungerade Element.</p>
    * 
    * @param werte Die zu durchsuchenden Werte. Alle Werte sind von null verschieden.
    * @param n Die gewünschte Position, Start bei 1.
    * 
    * @return Den Index des n-ten ungeraden Wertes falls es mindestens n ungerade Werte gibt, ansonsten
         {@link #INDEX_NOEXIST}.
    */
   static public int getNtesUngeradesElement(final int[] werte, final int n) {
      int anzahlUngerade = 0;

      for (int i = 0; i < werte.length; i++) {
         if (0 != werte[i] % 2) {
            anzahlUngerade++;
            if (n == anzahlUngerade) {
               return i;
            }
         }
      }
      return INDEX_NOEXIST;
   }   
}
