<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:d="http://docbook.org/ns/docbook"
  xmlns:m="http://www.w3.org/1998/Math/MathML"
  xmlns="http://www.w3.org/1999/xhtml"
  exclude-result-prefixes="d m"
  version="1.1">
  
  <xsl:import href="../Common/common.xsl"/>
  
  <xsl:variable name="topicLookup" select="document('topics.tid.xml', .)"/>
  
  <xsl:template name="user.webhelp.head.content">
    <xsl:param name="node"/>
    
    <xsl:copy-of select="$toggleDisplayScript"/>
    
    <xsl:if test="//m:math">
      <script type="text/x-mathjax-config">MathJax.Hub.Config({tex2jax: {inlineMath: [['$','$'], ['\\(','\\)']]}});</script>
      <script src="mathjax/MathJax.js?config=TeX-AMS-MML_HTMLorMML">
        <xsl:comment>Self closing tags disallowed!</xsl:comment>
      </script>
    </xsl:if>
  </xsl:template>
  
  <!-- No logo related parameter on offer, sigh! -->
  <xsl:template name="webhelpheader.logo">
    <a href="index.html">
      <img style='margin-right: 2px; height: 35px; padding-right: 25px; padding-top: 0px' align="right"
        src='{$webhelp.common.dir}images/hdmlogo.svg' alt="{$brandname} Documentation"/>
    </a>
  </xsl:template>
  
  <!-- copy mathml to output -->
  <xsl:template match="m:*">
    <xsl:element name="{local-name()}">
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="d:videodata">
    <video controls="controls" preload="auto">
      <xsl:attribute name="title">
        <xsl:value-of select="normalize-space(../../../d:title)"/>
      </xsl:attribute>
      
      <xsl:variable name="hdm_ImageFilename"> <!-- hdm_ prefix: do not mess with docbook! -->
        <xsl:call-template name="mediaobject.filename">
          <xsl:with-param name="object" select=".."/>
        </xsl:call-template>
      </xsl:variable>
      
      <source src="{$hdm_ImageFilename}" type='video/webm' />
      <source src="{$hdm_ImageFilename}.mp4" type='video/mp4'/>
      <xsl:text>Your Browser does not support the video tag</xsl:text>
    </video>
  </xsl:template>
  
  <!-- Modifying Docbook's standard -->
  
  <xsl:template match="d:qandaset">
    <xsl:variable name="title" select="(d:blockinfo/d:title|d:info/d:title|d:title)[1]"/>
    <xsl:variable name="preamble" select="*[local-name(.) != 'title'                                           and local-name(.) != 'titleabbrev'                                           and local-name(.) != 'qandadiv'                                           and local-name(.) != 'qandaentry']"/>
    <xsl:variable name="toc">
      <xsl:call-template name="pi.dbhtml_toc"/>
    </xsl:variable>
    
    <xsl:variable name="toc.params">
      <xsl:call-template name="find.path.params">
        <xsl:with-param name="table" select="normalize-space($generate.toc)"/>
      </xsl:call-template>
    </xsl:variable>
    
    <div>
      <xsl:apply-templates select="." mode="common.html.attributes"/>
      <xsl:call-template name="id.attribute">
        <xsl:with-param name="conditional" select="0"/>
      </xsl:call-template>
      <xsl:apply-templates select="$title"/>
      <xsl:if test="not($title)">
        <!-- andhor is output on title if there is one -->
        <xsl:call-template name="anchor">
          <xsl:with-param name="conditional" select="0"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="((contains($toc.params, 'toc') and $toc != '0') or $toc = '1')                   and not(ancestor::d:answer and not($qanda.nested.in.toc=0))">
        <xsl:call-template name="process.qanda.toc"/>
      </xsl:if>
      <xsl:apply-templates select="$preamble"/>
      <xsl:call-template name="process.qandaset"/>
    </div>
    
    <xsl:variable name="qandaId" select="@xml:id"/>
    <xsl:variable name="tid" select="$topicLookup/map/entry[@id = $qandaId]/@tid"/>
    <div class="bbForum" data-tid="{$tid}">
      <p>
        <a target="_blank">
          <xsl:attribute name="href">
            <xsl:text>https://bb.mi.hdm-stuttgart.de/topic/</xsl:text>
            <xsl:value-of select="$tid"/>
          </xsl:attribute>
          <xsl:text>Create comment</xsl:text>
        </a>
      </p>
    </div>
  </xsl:template>
  
  <!-- Modify navigation bar from webhelp-common.xsl -->
  
  <!-- The Header with the company logo -->
  <xsl:template name="webhelpheader">
    <xsl:param name="prev"/>
    <xsl:param name="next"/>
    <xsl:param name="nav.context"/>
    
    <xsl:variable name="home" select="/*[1]"/>
    <xsl:variable name="up" select="parent::*"/>
    
    <div id="header">
      <xsl:call-template name="webhelpheader.logo"/>
      <!-- Display the page title and the main heading(parent) of it-->
      <h1><!-- No top level info -->
        <xsl:choose>
          <xsl:when
            test="count($up) &gt; 0 and generate-id($up) != generate-id($home)">
            <xsl:apply-templates select="$up" mode="object.title.markup"/>
          </xsl:when>
          <xsl:when test="not(generate-id(.) = generate-id(/*))">
            <xsl:apply-templates select="." mode="object.title.markup"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="/*[1]" mode="title.markup"/>
          </xsl:otherwise>
        </xsl:choose>
      </h1>
      <!-- Prev and Next links generation-->
      <div id="navheader">
        <xsl:call-template name="user.webhelp.navheader.content"/>
        <xsl:comment>
                    <!-- KEEP this code. In case of neither prev nor next links are available, this will help to
                        keep the integrity of the DOM tree-->
                </xsl:comment>
        <!--xsl:with-param name="prev" select="$prev"/>
                <xsl:with-param name="next" select="$next"/>
                <xsl:with-param name="nav.context" select="$nav.context"/-->
        <table class="navLinks">
          <tr>
            <td>
              <a id="showHideButton" href="#" onclick="myLayout.toggle('west')"
                class="pointLeft" tabindex="5" title="Hide TOC tree">Sidebar
              </a>
            </td>
            <xsl:if test="count($prev) &gt; 0
              or (count($up) &gt; 0
              and generate-id($up) != generate-id($home)
              and $navig.showtitles != 0)
              or count($next) &gt; 0">
              <td>
                <xsl:if test="count($prev)>0">
                  <a accesskey="p" class="navLinkPrevious" tabindex="5">
                    <xsl:attribute name="href">
                      <xsl:call-template name="href.target">
                        <xsl:with-param name="object" select="$prev"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:call-template name="navig.content">
                      <xsl:with-param name="direction" select="'prev'"/>
                    </xsl:call-template>
                  </a>
                </xsl:if>
                
                <!-- "Up" link-->
                <xsl:choose>
                  <xsl:when test="count($up)&gt;0
                    and generate-id($up) != generate-id($home)">
                    |
                    <a accesskey="u" class="navLinkUp" tabindex="5">
                      <xsl:attribute name="href">
                        <xsl:call-template name="href.target">
                          <xsl:with-param name="object" select="$up"/>
                        </xsl:call-template>
                      </xsl:attribute>
                      <xsl:call-template name="navig.content">
                        <xsl:with-param name="direction" select="'up'"/>
                      </xsl:call-template>
                    </a>
                  </xsl:when>
                  <xsl:otherwise>&#160;</xsl:otherwise>
                </xsl:choose>
                
                <xsl:if test="count($next)>0">
                  |
                  <a accesskey="n" class="navLinkNext" tabindex="5">
                    <xsl:attribute name="href">
                      <xsl:call-template name="href.target">
                        <xsl:with-param name="object" select="$next"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:call-template name="navig.content">
                      <xsl:with-param name="direction" select="'next'"/>
                    </xsl:call-template>
                  </a>
                </xsl:if>
              </td>
            </xsl:if>
          </tr>
        </table>
      </div>
    </div>
  </xsl:template>
  
</xsl:stylesheet>
